@@ -8,7 +8,7 @@ from ..const import LockStatus
 _LOGGER = logging.getLogger(__name__)
 
 
-def process_wolock(data: bytes, mfr_data: bytes | None) -> dict[str, bool | int]:
+def process_wolock(data: bytes | None, mfr_data: bytes | None) -> dict[str, bool | int]:
     """Process woLock services data."""
     if mfr_data is None:
         return {}
@@ -17,7 +17,7 @@ def process_wolock(data: bytes, mfr_data: bytes | None) -> dict[str, bool | int]
     _LOGGER.debug("data: %s", data.hex())
 
     return {
-        "battery": data[2] & 0b01111111,
+        "battery": data[2] & 0b01111111 if data else None,
         "calibration": bool(mfr_data[7] & 0b10000000),
         "status": LockStatus(mfr_data[7] & 0b01110000),
         "update_from_secondary_lock": bool(mfr_data[7] & 0b00001000),
